#
# spec file for package curtail
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           curtail
Version:        1.10.0
Release:        2.1
Summary:        A simple and useful image compressor
License:        GPL-3.0-or-later
URL:            https://github.com/Huluti/curtail
Source0:        %{url}/archive/refs/tags/%{version}.tar.gz#/%{name}-%{version}.tar.gz
Source1:        %{name}-rpmlintrc
BuildRequires:  gobject-introspection-devel
BuildRequires:  gtk4-tools
BuildRequires:  hicolor-icon-theme
BuildRequires:  meson >= 0.50.0
BuildRequires:  pkgconfig
BuildRequires:  update-desktop-files
BuildRequires:  pkgconfig(glib-2.0)
# Note: Needs libadwaita's AboutWindow which is only available from version 1.2
BuildRequires:  pkgconfig(libadwaita-1) >= 1.2
Requires:       jpegoptim
Requires:       libwebp-tools
Requires:       optipng
Requires:       pngquant
Requires:       python3-gobject-Gdk
BuildArch:      noarch

%description
Curtail (previously ImCompressor) is an useful image compressor, supporting
PNG, JPEG and WEBP file types. It support both lossless and lossy compression
modes with an option to whether keep or not metadata of images.

%lang_package

%prep
%setup -q -n Curtail-%{version}

%build
%meson
%meson_build

%suse_update_desktop_file com.github.huluti.Curtail RasterGraphics

%install
%meson_install
%find_lang %{name} %{?no_lang_C}

%check
%meson_test

%files
%license COPYING
%doc CHANGELOG.md README.md
%{_bindir}/curtail
%{_datadir}/metainfo/*.xml
%{_datadir}/curtail/
%{_datadir}/applications/*.desktop
%{_datadir}/glib-2.0/schemas/*.xml
%{_datadir}/icons/hicolor/*/apps/*.svg

%files lang -f %{name}.lang

%changelog
* Tue Jun 18 2024 Atri Bhattacharya <badshah400@gmail.com>
- Update to version 1.10.0:
  * Add a "Recursive Compression" setting.
  * Update OxiPNG to v9.1.1
  * Change safe mode directly from warning banner button.
  * Fix opening files with "Open With...".
  * Fix DnD with nested folders (recursive).
  * Fix translations not applied to the help overlay window.
  * Updated translations.
- Run tests as part of %%check.
* Fri Apr 12 2024 Atri Bhattacharya <badshah400@gmail.com>
- Update to version 1.9.1:
  * Use default decoration layout for screenshots.
- Changes from version 1.9.0:
  * Correct title case, reword subtitles, remove periods.
  * Use proper arrow character.
  * Fix drag and drop for folders.
  * Appstream data improvements.
  * Updated translations.
- Empty %%check section as recommended by rpmlint.
* Wed Nov 22 2023 Atri Bhattacharya <badshah400@gmail.com>
- Update to version 1.8.0:
  - Add "Bulk Compress Directory (recursive)" feature.
  - Add simplified Chinese translation.
  - Add categories and keywords support in appdata.
  - Improve clarity of preference options.
  - Update OxiPNG to v9.
  - Handle cases where previews can't be generated.
  - Fix some "Format of this file is not supported".
  - Updated translations.
* Fri Apr 21 2023 Atri Bhattacharya <badshah400@gmail.com>
- Update to version 1.7.0:
  * Added:
  - SVG support.
  - Add a warning banner for overwrite mode.
  - New start screen with an AdwStatusPage.
  - Add debug information in about window.
  * Changed:
  - Switch from OptiPNG to Oxipng.
  - Minor UI improvements.
  - Remove some remaining dialogs.
  - Bump deps.
  * Fixed: Fix handling of filenames with spaces for WEBP
    compressor.
* Sat Apr  1 2023 Atri Bhattacharya <badshah400@gmail.com>
- Update to version 1.6.0:
  * New features:
  - Configurable compression timeout.
  - Compress images in an other thread.
  * Changes:
  - Better workflow for headerbar.
  - Move saving state in the subtitle.
  - Show errors on each line and not in modals anymore.
  - Simplify preferences.
  - Update translations.
  * Bug fix: Fix compression level ranges in UI.
- New BuildRequires: pkgconfig(libadwaita-1), gtk4-tools.
* Wed Jul 13 2022 Atri Bhattacharya <badshah400@gmail.com>
- Update to version 1.3.1:
  * Make size columns sortable.
  * Fix savings column sorting.
  * Updated translations.
* Sun May  1 2022 Atri Bhattacharya <badshah400@gmail.com>
- Update to version 1.3.0:
  * Add option to preserve file attributes if possible.
  * Update image libraries.
  * Updated translations.
* Tue Dec  7 2021 Atri Bhattacharya <badshah400@gmail.com>
- Update to version 1.2.2:
  * Updated translations.
* Fri Aug 27 2021 Atri Bhattacharya <badshah400@gmail.com>
- Actually add the rpmlintrc file to sources.
- BuildArch: noarch as recommended by rpmlint.
* Fri Aug 27 2021 Atri Bhattacharya <badshah400@gmail.com>
- Initial package.
- Add %%{name}-rpmlintrc to suppress explicit-lib-dependency
  trigerred for libwebp-tools Requires.
